@@ -344,7 +344,7 @@ class JobServer ():
         # get the sock from the session
         s = socket.fromfd(response.raw.fileno(), socket.AF_INET, socket.SOCK_STREAM)
         # get the address from the socket
-        address = s.getsockname()
+        address, _ = s.getsockname()
         self.ip_address=address
       
     # if we get a response.status_code == 200, we're ok.  If not,
